@@ -134,8 +134,8 @@ void PartMan::scan(DeviceItem *drvstart)
         drvit->device = jdName;
         drvit->path = jdPath;
         const QString &ptType = jsonDrive["pttype"].toString();
-        drvit->flags.curGPT = (ptType=="gpt");
-        drvit->flags.curMBR = (ptType=="dos");
+        drvit->flags.curGPT = (ptType == "gpt");
+        drvit->flags.curMBR = (ptType == "dos");
         drvit->flags.rotational = jsonDrive["rota"].toBool();
         drvit->discgran = jsonDrive["disc-gran"].toInt();
         drvit->size = jsonDrive["size"].toVariant().toLongLong();
@@ -163,7 +163,7 @@ void PartMan::scan(DeviceItem *drvstart)
             if ((partflags & 0x80) || (partflags & 0x04)) partit->setActive(true);
             partit->mapCount = jsonPart["children"].toArray().count();
             partit->flags.curESP = partTypeName.startsWith("EFI "); // "System"/"(FAT-12/16/32)"
-            partit->flags.bootRoot = (!bootUUID.isEmpty() && jsonPart["uuid"]==bootUUID);
+            partit->flags.bootRoot = (!bootUUID.isEmpty() && jsonPart["uuid"] == bootUUID);
             partit->curFormat = jsonPart["fstype"].toString();
             // Touching MacOS first drive, or MS LDM may brick the system.
             if ((proc.detectMac() && partit->device.startsWith("sda"))
@@ -257,7 +257,7 @@ void PartMan::scanVirtualDevices(bool rescan)
             devit->discgran = discgran;
             devit->size = size;
             devit->physec = physec;
-            devit->flags.bootRoot = (!bootUUID.isEmpty() && jsonDev["uuid"]==bootUUID);
+            devit->flags.bootRoot = (!bootUUID.isEmpty() && jsonDev["uuid"] == bootUUID);
             devit->curLabel = label;
             devit->curFormat = jsonDev["fstype"].toString();
             devit->flags.volCrypto = crypto;
@@ -676,7 +676,7 @@ void PartMan::scanSubvolumes(DeviceItem *partit)
     proc.exec("btrfs", {"subvolume", "list", "/mnt/btrfs-scratch"}, nullptr, true);
     lines = proc.readOutLines();
     proc.exec("umount", {"/mnt/btrfs-scratch"});
-    for (const QString &line : lines) {
+    for (const QString &line : qAsConst(lines)) {
         const int start = line.indexOf("path") + 5;
         if (line.length() <= start) goto END;
         DeviceItem *svit = new DeviceItem(DeviceItem::Subvolume, partit);
@@ -966,7 +966,7 @@ void PartMan::preparePartitions()
             // Using the existing layout, so only mark used partitions for unmounting.
             for (int ixPart=0; ixPart < partCount; ++ixPart) {
                 DeviceItem *twit = drvit->child(ixPart);
-                if (!twit->usefor.isEmpty()) listToUnmount << twit->device;
+                if (!twit->usefor.isEmpty()) listToUnmount << twit->path;
             }
         } else {
             // Clearing the drive, so mark all partitions on the drive for unmounting.
@@ -974,9 +974,11 @@ void PartMan::preparePartitions()
             listToUnmount << proc.readOutLines();
         }
     }
-    for (const QString &devpath : listToUnmount) {
-        proc.exec("swapoff", {devpath});
-        proc.exec("/bin/umount", {devpath});
+    proc.exec("swapon", {"--show=NAME", "--noheadings"}, nullptr, true);
+    const QStringList swaps = proc.readOutLines();
+    for (const QString &devpath : qAsConst(listToUnmount)) {
+        if (swaps.contains(devpath)) proc.exec("swapoff", {devpath});
+        else proc.exec("/usr/bin/umount", {"-q", devpath});
     }
 
     // Prepare partition tables on devices which will have a new layout.
@@ -1147,7 +1149,7 @@ void PartMan::prepareSubvolumes(DeviceItem *partit)
         throw msgfail;
     }
     bool ok = true;
-    for (const QString &subvol : svlist) {
+    for (const QString &subvol : qAsConst(svlist)) {
         proc.exec("btrfs", {"subvolume", "delete", "/mnt/btrfs-scratch/" + subvol});
         ok = proc.exec("btrfs", {"subvolume", "create", "/mnt/btrfs-scratch/" + subvol});
         if (!ok) break;
@@ -1388,7 +1390,7 @@ int PartMan::isEncrypt(const QString &point)
 {
     int count = 0;
     if (point.isEmpty()) {
-        for (DeviceItem *twit : mounts) {
+        for (DeviceItem *twit : qAsConst(mounts)) {
             if (twit->willEncrypt()) ++count;
         }
     } else if (point == "SWAP") {
@@ -1711,7 +1713,7 @@ DeviceItem::~DeviceItem()
         const int r = parentItem->indexOfChild(this);
         partman->beginRemoveRows(partman->index(parentItem), r, r);
     }
-    for (DeviceItem *cit : children) {
+    for (DeviceItem *cit : qAsConst(children)) {
         cit->partman = nullptr; // Stop unnecessary signals.
         cit->parentItem = nullptr; // Stop double deletes.
         delete cit;
@@ -1730,7 +1732,7 @@ void DeviceItem::clear()
 {
     const int chcount = children.count();
     if (partman && chcount > 0) partman->beginRemoveRows(partman->index(this), 0, chcount - 1);
-    for (DeviceItem *cit : children) {
+    for (DeviceItem *cit : qAsConst(children)) {
         cit->partman = nullptr; // Stop unnecessary signals.
         cit->parentItem = nullptr; // Stop double deletes.
         delete cit;
@@ -1770,7 +1772,7 @@ void DeviceItem::sortChildren()
     };
     std::sort(children.begin(), children.end(), cmp);
     if (partman) {
-        for (DeviceItem *c : children) partman->notifyChange(c);
+        for (DeviceItem *c : qAsConst(children)) partman->notifyChange(c);
     }
 }
 /* Helpers */
@@ -2016,8 +2018,8 @@ void DeviceItem::autoFill(unsigned int changed)
                 }
                 options.clear();
                 if (!flags.rotational) {
-                    const bool btrfs = (format=="btrfs" || type==Subvolume);
-                    if (discgran && (format=="ext4" || format=="xfs")) options = "discard,";
+                    const bool btrfs = (format == "btrfs" || type == Subvolume);
+                    if (discgran && (format == "ext4" || format == "xfs")) options = "discard,";
                     else if (discgran && btrfs) options = "ssd,discard=async,";
                     else if (btrfs) options = "ssd,";
                 }
@@ -2058,7 +2060,7 @@ int DeviceItem::layoutDefault(int rootPercent, bool crypto, bool updateTree)
     const int bootMinMB = static_cast<int>(partman->bootSpaceNeeded / 1048576);
     if (!crypto) rootMinMB += bootMinMB;
     else {
-        int bootFormatSize = 512;
+        int bootFormatSize = 1024;
         if (bootFormatSize < bootMinMB) bootFormatSize = static_cast<int>(partman->bootSpaceNeeded);
         if (updateTree) addPart(bootFormatSize, "boot", crypto);
         rootFormatSize -= bootFormatSize;
